# noinspection PyClassHasNoInit
class ClientOption:
    DEBUG = 'debug'
    PID_FILE = 'pid_file'
    LOG_FILE = 'log_file'
    LOG_LEVEL = 'log_level'
    DEVICE_ID = 'device_id'
    PIN_LOGOUT = 'pin_logout'
    CONFIG_FILE = 'config_file'
    PIN_LED_RED = 'pin_led_red'
    STATUS_FILE = 'status_file'
    PIN_LED_BLUE = 'pin_led_blue'
    REBOOT_DELAY = 'reboot_delay'
    FORCE_UPDATE = 'force_update'
    PIN_LED_GREEN = 'pin_led_green'
    SERVER_ADDRESS = 'server_address'
    REBOOT_ON_ERROR = 'reboot_on_error'
    PIN_POWER_RELAY = 'pin_power_relay'
    SERIAL_PORT_NAME = 'serial_port_name'
    SERIAL_PORT_SPEED = 'serial_port_speed'
    PIN_CURRENT_SENSE = 'pin_current_sense'
    LOGOUT_COAST_TIME = 'logout_coast_time'
    LOGGING_CONFIG_FILE = 'logging_config_file'
    MAX_POWER_DOWN_TIMEOUT = 'max_power_down_timeout'
